package cfbd_client

import (
    "encoding/json"
    "fmt"
    "net/http"
    "net/url"
    "time"
    "discord-cfb-bot/config"
)

type Game struct {
    HomeTeam      string `json:"home_team"`
    AwayTeam      string `json:"away_team"`
    HomePoints    *int   `json:"home_points"`
    AwayPoints    *int   `json:"away_points"`
    StartDateTime string `json:"start_date"`
}

type ScoreboardGame struct {
    HomeTeam      string `json:"home_team"`
    AwayTeam      string `json:"away_team"`
    HomePoints    *int   `json:"home_points"`
    AwayPoints    *int   `json:"away_points"`
    StartDateTime string `json:"start_date"`
    Status        string `json:"status"`
}

func getCurrentWeek() int {
    seasonStartDate := "2024-08-28" // Replace with actual season start date
    startDate, _ := time.Parse("2006-01-02", seasonStartDate)
    weeks := int(time.Since(startDate).Hours() / (24 * 7))
    return weeks + 1
}

func getLiveGame(teamName string) string {
    url := "https://api.collegefootballdata.com/scoreboard"
    currentWeek := getCurrentWeek()
    params := fmt.Sprintf("?year=%d&week=%d", time.Now().Year(), currentWeek)

    req, _ := http.NewRequest("GET", url+params, nil)
    req.Header.Set("Authorization", "Bearer "+config.CFBDAPIKey)

    client := &http.Client{}
    resp, err := client.Do(req)
    if err != nil {
        fmt.Println("Error fetching data from scoreboard API:", err)
        return "Error fetching live game data."
    }
    defer resp.Body.Close()

    var games []ScoreboardGame
    if err := json.NewDecoder(resp.Body).Decode(&games); err != nil {
        fmt.Println("Error decoding scoreboard response:", err)
        return "Error parsing live game data."
    }

    for _, game := range games {
        if game.Status == "in_progress" && (game.HomeTeam == teamName || game.AwayTeam == teamName) {
            return fmt.Sprintf("Live: %s: %d %s: %d", game.AwayTeam, *game.AwayPoints, game.HomeTeam, *game.HomePoints)
        }
    }

    return "No live games found for the team."
}

func GetGameInfo(teamName string) string {
    apiUrl := "https://api.collegefootballdata.com/games"
    currentWeek := getCurrentWeek()
    queryParams := fmt.Sprintf("?year=%d&week=%d&team=%s", time.Now().Year(), currentWeek, url.QueryEscape(teamName))

    req, _ := http.NewRequest("GET", apiUrl+queryParams, nil)
    req.Header.Set("Authorization", "Bearer "+config.CFBDAPIKey)

    client := &http.Client{}
    resp, err := client.Do(req)
    if err != nil {
        fmt.Println("Error fetching data:", err)
        return "Error fetching game info."
    }
    defer resp.Body.Close()

    var games []Game
    if err := json.NewDecoder(resp.Body).Decode(&games); err != nil {
        fmt.Println("Error decoding response:", err)
        return "Error parsing game data."
    }

    for _, game := range games {
        startTime, _ := time.Parse(time.RFC3339, game.StartDateTime)

        // Load Eastern Time location
        eastern, err := time.LoadLocation("America/New_York")
        if err != nil {
            fmt.Println("Error loading Eastern timezone:", err)
            return "Error fetching game time."
        }
        startTimeEastern := startTime.In(eastern)

        if time.Now().After(startTime) && game.HomePoints != nil && game.AwayPoints != nil {
            return fmt.Sprintf("%s: %d %s: %d", game.AwayTeam, *game.AwayPoints, game.HomeTeam, *game.HomePoints)
        } else if time.Now().Before(startTime) {
            return fmt.Sprintf("%s @ %s %s Eastern", game.AwayTeam, game.HomeTeam, startTimeEastern.Format("03:04 PM"))
        }
    }

    // Call the getLiveGame function if no specific game is found
    liveGameResult := getLiveGame(teamName)
    if liveGameResult != "No live games found for the team." {
        return liveGameResult
    }

    return "No recent, upcoming, or live games found for the team."
}

